#!/usr/bin/env python
from codecs import open
from setuptools import setup, find_packages

import lintlens


packages = find_packages(include=('lintlens*',), exclude=('*.tests',))


requires = [
    'six>=1.9.0',
]

tests_require = [
    'pytest>=3.7.0',
]


with open('README.md', 'r', 'utf-8') as f:
    readme = f.read()

setup(
    name='lintlens',
    version=lintlens.__version__,
    description='Filters lint report and keep only defects on changed lines',
    long_description=readme,
    author='Dragan Bosnjak',
    url='https://github.com/draganHR/lintlens',
    packages=packages,
    include_package_data=True,
    zip_safe=False,
    classifiers=(
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.6',
    ),
    install_requires=requires,
    extras_require={
        'tests': tests_require,
    },

    entry_points={
        'console_scripts': [
            'lintlens = lintlens.cli:main',
        ]
    },
    test_suite='tests'
)



import pytest

from lintlens.utils import check_line_in_range


def test_check_line_in_range_first_line():
    args = 1, 1, 0
    assert check_line_in_range(0, *args) is False
    assert check_line_in_range(1, *args) is True
    assert check_line_in_range(2, *args) is False


@pytest.mark.parametrize('range_count', (1, 2, 3, 4, 5))
def test_check_line_in_range_for_range_count(range_count):
    args = 42, range_count, 0
    for i in range(3):
        assert check_line_in_range(41 - i, *args) is False
    for i in range(range_count):
        assert check_line_in_range(42 + i, *args) is True
    for i in range(3):
        assert check_line_in_range(43 + i + range_count, *args) is False
